==> ikapi-0.8.0.tgz: package/src/IKProcess.js <==
//Components
import Utils  from "./API/IKUtils";
import IKDB from "./Database/IKDB";
import IKLogger from "./Logger/IKLogger";
import IKGlobals from './IKGlobals';
import IKValidation from './Validation/IKValidation';
//
export default class IKProcess {
  constructor(config, interval) {
    this.interval = interval;
    this.logger = new IKLogger({/*COFIG S3/SQS HERE*/}, Utils.logLevel());
    this.db = new IKDB(config.database);
    this.validator = new IKValidation(config.validation);
  }

  //Main interface
  async execute(executionFunc) {
    await this._executeLoggerFlush(async ()=>{
      await this._executeDBTransactions(async ()=>{
        //program loop
        setInvertal( async () => {
          await this._execute(executionFunc);
        });
        //
        while (true) await Utils.sleep(this.interval);
      });
    });
  }
  //Executions
  async _execute(executionFunc) {
    let executionFailed = true; //failled til we say no!
    //safe execution handler
    try { //Execute
      console.debug("Starting main request code");
      await executionFunc(this);
      executionFailed = false;
    } catch (e) { /*EXECUTION FAIL*/
      console.error('Exception when executing main request code.');
      console.exception(e);
    } return executionFailed;
  }
  async _executeDBTransactions(safeExecution) {
    try {
      let executionFailed = await safeExecution();
      if (!executionFailed) await this.db.runQueuedQueries();
      else console.log("Skipping pending DB transactions. Main code failed!");
    } catch (e) {
      console.error('Exception when executing DB transactions.');
      console.log(e);
    }
  }
  async _executeLoggerFlush(safeExecution) {
    try {
      await safeExecution();
      await this.logger.flushLogs();
    } catch (e) {
      console.error('Exception when flushing logs.');
      console.exception(e);
    } finally {
      console.debug("Transaction ended");
    }
  }
}

==> ikapi-0.8.1.tgz: package/src/IKProcess.js <==
//Components
import Utils  from "./API/IKUtils";
import IKDB from "./Database/IKDB";
import IKLogger from "./Logger/IKLogger";
import IKGlobals from './IKGlobals';
import IKValidation from './Validation/IKValidation';
//
export default class IKProcess {
  constructor(config, interval) {
    this.interval = interval;
    this.logger = new IKLogger({/*COFIG S3/SQS HERE*/}, Utils.logLevel());
    this.db = new IKDB(config.database);
    this.validator = new IKValidation(config.validation);
  }

  //Main interface
  async execute(executionFunc) {
    await this._executeLoggerFlush(async ()=>{
      await this._executeDBTransactions(async ()=>{
        //program loop
        setInterval( async () => {
          await this._execute(executionFunc);
        });
        //
        while (true) await Utils.sleep(this.interval);
      });
    });
  }
  //Executions
  async _execute(executionFunc) {
    let executionFailed = true; //failled til we say no!
    //safe execution handler
    try { //Execute
      console.debug("Starting main request code");
      await executionFunc(this);
      executionFailed = false;
    } catch (e) { /*EXECUTION FAIL*/
      console.error('Exception when executing main request code.');
      console.exception(e);
    } return executionFailed;
  }
  async _executeDBTransactions(safeExecution) {
    try {
      let executionFailed = await safeExecution();
      if (!executionFailed) await this.db.runQueuedQueries();
      else console.log("Skipping pending DB transactions. Main code failed!");
    } catch (e) {
      console.error('Exception when executing DB transactions.');
      console.log(e);
    }
  }
  async _executeLoggerFlush(safeExecution) {
    try {
      await safeExecution();
      await this.logger.flushLogs();
    } catch (e) {
      console.error('Exception when flushing logs.');
      console.exception(e);
    } finally {
      console.debug("Transaction ended");
    }
  }
}
